/* -*-mode:C;c-basic-offset:8-*-
 * Copyright (C) 1995-1996 Claus-Justus Heine

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; see the file COPYING.  If not, write to
the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

 *
 $Source: /homes/cvs/zftape/zftape-ioctl.h,v $
 $Author: claus $
 *
 $Revision: 1.3 $
 $Date: 1996/03/02 12:42:16 $
 $State: Exp $
 *
 *  special ioctl for zftape
 *
 */
#ifndef _FTAPE_IOCTL_H
#define _FTAPE_IOCTL_H


/*
 *   the following are meant for raw access only. The driver ignores them if 
 *   the driver is not accessed via one of the raw devices /dev/rawft*
 */
#ifndef _FTAPE_H

typedef struct {
	__u16 segment;
	__u16 date;
} FailedSectorLogEntry;

typedef __u32 SectorMap;

/*  failed sector log size (only used if format code != 4).
 */
#define SECTOR_SIZE 1024
#define FAILED_SECTOR_LOG_SIZE  (2 * SECTOR_SIZE - 256)
#define MAX_FAILED_SECTORS (FAILED_SECTOR_LOG_SIZE/sizeof(EofMark))
#define BAD_SECTOR_MAP_SIZE     (29 * SECTOR_SIZE - 256)

#endif /* _FTAPE_H */

/*
 *  the following simple structure is used to read or write a single segment
 *  One may also read and write the header segments, but that means that
 *  one has to act really careful, because zftape no any other tape program
 *  will be able to read or write to a tape any longer if garbage is written
 *  to the header segments.
 */
struct mtqic80segment
{            
	unsigned  seg_num;  /* the segment to read or write, always written to
			     * kernel space 
			     */
	int result;         /* the result of read_segment() or write_segment(),
			     * always read from kernel space
			     * the ioctl will try only once to read or write the 
			     * segment, the user must decide himself whether
			     * he wants to repeat
			     */
	byte *data;         /* pointer to the buffer in user space. This buffer 
			     * must have at least 29kb.
			     */
};
 
/*
 *  _IOW is alright in both cases, because we write the addresses of the pointers
 *  to the kernel. ftape_ioctl() then calls verify_area() on each pointer.
 */
#define	MTIOC_ZFTAPE_GETSEG _IOWR('m', 100, struct mtqic80segment)  /* read a segment */
#define	MTIOC_ZFTAPE_SETSEG _IOWR('m', 101, struct mtqic80segment)   /* write a segment */

/*
 *   let the user know at which block size the volume was created with
 *   this is important as we let the user change the blocksize with
 *   MTSETBLK. One can query the blocksize before reading an old 
 *   volume or before appending data to it. zftape does not allow
 *   read/write access with the wrong blocksize. This is rather
 *   unproblematic as long as people use tar with the standard blocksize
 *   of 10kb which is also zftapes default blocksize, but who knows :-)
 */
struct mtblksz {
	unsigned long mt_blksz;
};
#define MTIOC_ZFTAPE_GETBLKSZ _IOR('m', 104, struct mtblksz)

#endif









